summaryrefslogtreecommitdiffstats
path: root/src/com/android/camera/filmstrip
diff options
context:
space:
mode:
authorAngus Kong <shkong@google.com>2014-02-20 16:56:37 -0800
committerAngus Kong <shkong@google.com>2014-02-20 18:36:46 -0800
commitc195e7a9208c90d7a55e184d4b2b9c747e9c90f1 (patch)
treef0780dfd77ad2965713ec6fec707fb4d655d5cc4 /src/com/android/camera/filmstrip
parenta303a71ff636535e59bd356bda40e9a324699357 (diff)
downloadandroid_packages_apps_Camera2-c195e7a9208c90d7a55e184d4b2b9c747e9c90f1.tar.gz
android_packages_apps_Camera2-c195e7a9208c90d7a55e184d4b2b9c747e9c90f1.tar.bz2
android_packages_apps_Camera2-c195e7a9208c90d7a55e184d4b2b9c747e9c90f1.zip
Tweak the peek animation image size.
bug:12451161 Change-Id: Ie5a8a2911ed4b5ce831331ca7e7600d6d13659b7
Diffstat (limited to 'src/com/android/camera/filmstrip')
-rw-r--r--src/com/android/camera/filmstrip/ImageData.java6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/com/android/camera/filmstrip/ImageData.java b/src/com/android/camera/filmstrip/ImageData.java
index 52f8ffa01..6a51d3e36 100644
--- a/src/com/android/camera/filmstrip/ImageData.java
+++ b/src/com/android/camera/filmstrip/ImageData.java
@@ -73,10 +73,10 @@ public interface ImageData {
public int getHeight();
/**
* Returns the orientation of the image in degrees. The valid values are
* 0, 90, 180, and 270.
*/
- public int getOrientation();
+ public int getRotation();
/** Returns the image data type. The current valid values are
* {@code VIEW_TYPE_*}.
@@ -73,10 +73,10 @@ public interface ImageData {
public int getHeight();
/**
- * Returns the orientation of the image in degrees. The valid values are
- * 0, 90, 180, and 270.
+ * Returns the rotation of the image in degrees clockwise. The valid values
+ * are 0, 90, 180, and 270.
*/